summary refs log tree commit diff
path: root/pkgs/tools/games
diff options
context:
space:
mode:
authorWeijia Wang <9713184+wegank@users.noreply.github.com>2023-03-06 23:12:55 +0200
committerWeijia Wang <9713184+wegank@users.noreply.github.com>2023-03-06 23:12:55 +0200
commit9b985ffb118dc36281b728570c1bc77ca4bd9ef4 (patch)
tree095a583bf5200dee47ac250a4dd84a81dc653f9d /pkgs/tools/games
parent27390e6807788f7da8150dab9a55277d0ff1c1b8 (diff)
weidu: patch against OCaml 4.14
Diffstat (limited to 'pkgs/tools/games')
-rw-r--r--pkgs/tools/games/weidu/default.nix7
1 files changed, 5 insertions, 2 deletions
diff --git a/pkgs/tools/games/weidu/default.nix b/pkgs/tools/games/weidu/default.nix
index 91c6217d893a2..f63e5d41d3fe4 100644
--- a/pkgs/tools/games/weidu/default.nix
+++ b/pkgs/tools/games/weidu/default.nix
@@ -9,10 +9,10 @@
 }:
 
 let
   # 1. Needs ocaml >= 4.04 and <= 4.11
   # 2. ocaml 4.10 defaults to safe (immutable) strings so we need a version with
   #    that disabled as weidu is strongly dependent on mutable strings
-  ocaml' = ocaml-ng.ocamlPackages_4_11.ocaml.override {
+  ocaml' = ocaml-ng.ocamlPackages_4_14.ocaml.override {
     unsafeStringSupport = true;
   };
 
@@ -34,6 +34,9 @@ stdenv.mkDerivation rec {
       --replace elkhound ${elkhound}/bin/elkhound
 
     mkdir -p obj/{.depend,x86_LINUX}
+
+    # undefined reference to `caml_hash_univ_param'
+    sed -i "20,21d;s/old_hash_param/hash_param/" hashtbl-4.03.0/myhashtbl.ml
   '';
 
   nativeBuildInputs = [ elkhound ocaml' perl which gnumake42 ];
@@ -9,10 +9,10 @@
 
 let
-  # 1. Needs ocaml >= 4.04 and <= 4.11
+  # 1. Needs ocaml >= 4.04 and <= 4.11 (patched against 4.14)
   # 2. ocaml 4.10 defaults to safe (immutable) strings so we need a version with
   #    that disabled as weidu is strongly dependent on mutable strings